<?php

namespace App\Dto\Input;

use App\Dto\Output\OrganizationalUnitOutput;
use App\Entity\OrganizationalUnit;
use App\Model\OrganizationalUnitTypes;
use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Validator\Constraints as Assert;

final class OrganizationalUnitClassroomInput
{
    #[Assert\NotBlank]
    #[Groups(['organizational-unit:write'])]
    public ?string $name = null;

    #[Assert\NotNull]
    #[Groups(['organizational-unit:write'])]
    public ?OrganizationalUnitOutput $parent = null;

    #[Groups(['organizational-unit:write'])]
    public ?string $description = null;

    #[Groups(['organizational-unit:write'])]
    public ?string $comments = null;

    #[Groups(['organizational-unit:write'])]
    public ?string $location = null;

    #[Groups(['organizational-unit:write'])]
    public ?bool $projector = null;

    #[Groups(['organizational-unit:write'])]
    public ?bool $board = null;

    #[Groups(['organizational-unit:write'])]
    public ?int $capacity = null;

    public function __construct(?OrganizationalUnit $organizationalUnit = null)
    {
        if (!$organizationalUnit) {
            return;
        }

        $this->name = $organizationalUnit->getName();
        $this->parent = $organizationalUnit->getParent();
        $this->description = $organizationalUnit->getDescription();
        $this->comments = $organizationalUnit->getComments();
        $this->location = $organizationalUnit->getLocation();
        $this->projector = $organizationalUnit->isProjector();
        $this->board = $organizationalUnit->isBoard();
        $this->capacity = $organizationalUnit->getCapacity();
    }

    public function createOrUpdateEntity(?OrganizationalUnit $organizationalUnit = null): OrganizationalUnit
    {
        if (!$organizationalUnit) {
            $organizationalUnit = new OrganizationalUnit();
        }

        $organizationalUnit->setName($this->name);
        $organizationalUnit->setType(OrganizationalUnitTypes::CLASSROOM);
        $organizationalUnit->setParent($this->parent->getEntity());
        $organizationalUnit->setDescription($this->description);
        $organizationalUnit->setComments($this->comments);
        $organizationalUnit->setLocation($this->location);
        $organizationalUnit->setProjector($this->projector);
        $organizationalUnit->setBoard($this->board);
        $organizationalUnit->setCapacity($this->capacity);

        return $organizationalUnit;
    }
}